# Generated by Django 2.1.2 on 2019-02-24 11:44

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_saas_email', '0005_mail_bcc_address'),
    ]

    operations = [
        migrations.AddField(
            model_name='mail',
            name='from_name',
            field=models.CharField(blank=True, help_text='Email sender name', max_length=100, null=True, verbose_name='Sender name'),
        ),
        migrations.AddField(
            model_name='mail',
            name='to_name',
            field=models.CharField(blank=True, help_text='Email recipient name', max_length=100, null=True, verbose_name='Recipient name'),
        ),
    ]



from django.conf import settings
from django.apps import apps
from .models import Mail

task_queue = getattr(settings, "DJANGO_SAAS_EMAIL_TASK_QUEUE", "celery")
decorator_kwargs = getattr(settings, "DJANGO_SAAS_EMAIL_DECORATOR_KWARGS", {})

if task_queue == "celery":
    from celery import shared_task as task_decorator
elif task_queue == "rq":
    from django_rq import job as task_decorator
else:
    raise RuntimeError("Only `celery` and `rq` task queues are supported.")


@task_decorator(**decorator_kwargs)
def send_asynchronous_mail(mail_uuid, sendgrid_api=False):
    """Send an asynchronous mail by the given ID."""
    try:
        app_model_name = settings.DJANGO_SAAS_EMAIL_MAIL_MODEL
    except AttributeError:
        mail_model = Mail
    else:
        app_label, model_name = app_model_name.split(".")
        mail_model = apps.get_model(app_label, model_name)
    try:
        mail = mail_model.objects.get(id=mail_uuid)
    except Mail.DoesNotExist:
        raise AttributeError("There is no mail with that UUID")

    mail.send(sendgrid_api=sendgrid_api)



# Generated by Django 2.1.2 on 2019-03-28 14:39

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_saas_email', '0006_add_to_and_from_names'),
    ]

    operations = [
        migrations.AddField(
            model_name='mailtemplate',
            name='sender_email',
            field=models.EmailField(blank=True, help_text='Email to use as sender address when the template is used. If not set then default address is used', max_length=254, null=True),
        ),
    ]



from .models import Mail
from .tasks import send_asynchronous_mail
from django.conf import settings


def create_and_send_mail(**kwargs):
    """Helper method to create and send a mail.

    create_and_send_mail(template_name="hello", context={'name': 'Jens'}, to_address="me@jensneuhaus.de")
    """
    mail = Mail.objects.create_mail(**kwargs)
    send_asynchronous_mail.delay(
        mail.id, sendgrid_api=getattr(settings, "SENDGRID_API_KEY", False)
    )
